@@ -148,7 +148,7 @@ repository = %(repository_path)s
             )
           if status_dict['status_code'] != 0:
             safeRpcCall(master.reportTaskFailure,
-              test_result, status_dict, config['test_suite_title'])
+              test_result_path, status_dict, config['test_suite_title'])
             continue
           run_software = False
 
